require(lme4)
require(lmerTest)
require(ggplot2)
library(ggdendro)

#models for the rime discrimination experiment (Experiment 1)
#random slopes are not possible because participants were divided between coda conditions
rimedis_acc =
  glmer(TargetSoundOut.ACC~Coda
        *C(RealWord, rimedis_contr_rw)
        +(1|Participant),
        family = binomial(), data = rimedis_culled,
        control = glmerControl(optimizer="bobyqa", optCtrl = list(maxfun=10^9)))
summary(rimedis_acc)

rimedis_rt =
  glmer(TargetSoundOut.RT~Coda
        *C(RealWord, rimedis_contr_rw)
        +(1|Participant),
        family = gaussian(link=log), data = rimedis_culled_correct,
        control = glmerControl(optimizer="bobyqa", optCtrl = list(maxfun=10^9)))
summary(rimedis_rt)

rimedis_speed_accuracy_tradeoff = 
  glmer(TargetSoundOut.RT~Coda
        *AccuracyFact
        +C(RealWord, rimedis_contr_rw)
        +(1|Participant),
        family = gaussian(link = log), data = rimedis_culled,
        control = glmerControl(optimizer="bobyqa", optCtrl = list(maxfun=10^9)))
summary(rimedis_speed_accuracy_tradeoff)

##visualising perceptual vowel similarity with dendrograms
theme_article <- function () { 
  theme_bw(base_size= 20, base_family="sans") %+replace% 
    theme(plot.title = element_text(size = 22,  hjust = 0, vjust = 3),
          axis.title = element_text(size = 22),
          axis.text = element_text(size=20), 
          legend.text = element_text(size = 22)
          #reduce white space around plot to save space
          #plot.margin = margin(0.1, 0.1, 0.1, 0.1, "cm"),
    )
}


theme_set(theme_bw(base_size = 20, base_family = "sans"))

cor1 <- cor(rimedis_conf_d)
dist1<-dist(cor1)
hc1<-hclust(dist1, method = "ward.D2")
dend1 <- as.dendrogram(hc1)
dend_data1 <- dendro_data(dend1, type = "rectangle")


cor2 <- cor (rimedis_conf_l)
dist2<-dist(cor2)
hc2<-hclust(dist2, method = "ward.D2")
dend2 <- as.dendrogram(hc2)
dend_data2 <- dendro_data(dend2, type = "rectangle")

fig_dendro_d <-
  ggplot(dend_data1$segments) + 
  geom_segment(aes(x = x, y = y, xend = xend, yend = yend))+
  ylim(-0.25, 3.2)  +
  ylab("Vowel confusability") +
  scale_x_continuous(breaks = seq(0, 0, by = 0), name ="")+
  theme_article() +
  theme(legend.position=c(0.15,0.15), 
        panel.grid.major = element_blank(), panel.grid.minor = element_blank()
  ) +
  geom_text(data = dend_data1$labels, aes(x, y, label = label),
            hjust = 0.5, vjust = 1.5, angle = 0,  size = 7
  )

fig_dendro_l <-
  ggplot(dend_data2$segments) + 
  geom_segment(aes(x = x, y = y, xend = xend, yend = yend))+
  ylim(-0.25, 3.2)  +
  ylab("Vowel confusability") +
  scale_x_continuous(breaks = seq(0, 0, by = 0), name ="")+
  theme_article() +
  theme(legend.position=c(0.15,0.15), 
        panel.grid.major = element_blank(), panel.grid.minor = element_blank()
  ) +
  geom_text(data = dend_data2$labels, aes(x, y, label = label),
            hjust = 0.5, vjust = 1.5, angle = 0,  size = 7
  )

#models for the word recognition experiment (Experiment 2)
##accuracy
wordrec_acc =
  glmer(AnswerCorrectNum~Coda
        *C(Vowel, contr.sum)
        +LogNormFreq
        +(1+Coda|Participant),
        family = binomial(), data = wordrec_culled,
        control = glmerControl(optimizer="bobyqa", optCtrl = list(maxfun=10^9)))
summary(wordrec_acc)

##rt
wordrec_rt=
  glmer(RT1~Coda
        *C(Vowel, contr.sum)
        +LogNormFreq
        +(1+Coda|Participant),
        family = gaussian(link=log), data = wordrec_culled_correct,
        control = glmerControl(optimizer="bobyqa", optCtrl = list(maxfun=10^9)))
summary(wordrec_rt) 


##validating that accuracy effects is driven by minimal pair errors
wordrec_acc_competitor_errors =
  glmer(AnswerCorrectNum~Coda
        +C(Vowel, contr.sum)
        +LogNormFreq
        +(1+Coda|Participant),
        family = binomial(), data = wordrec_culled %>%  filter(AnswerCorrect == "1" | CompetitorError == 1),
        control = glmerControl(optimizer="bobyqa", optCtrl = list(maxfun=10^9)))
summary(wordrec_acc_competitor_errors)


##test vowel level coding
print(attributes(C(wordrec_culled_correct$Vowel, contr.sum, 7)))

